# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from collections import namedtuple

from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.scopes.apps import (
    launch_application_from_apps_scope
)
from ubuntu_system_tests.helpers.unity8 import (
    close_app, launch_application_from_launcher
)

APP = 'address-book-app'
APP_NAME = 'Contacts'
APP_WIN_ID = 'address-book-app'


Contact = namedtuple('Contact', ['name', 'number', 'expected_reply'])
Contact.__new__.__defaults__ = (None, None, None)


def launch_address_book():
    """
    Launch the address book app from apps scope and return proxy object.

    :return: Proxy object for address book application.

    """
    launch_application_from_apps_scope(APP_NAME)
    return get_address_book_app_proxy()


def close_address_book():
    """ Close the address book app using task switcher """
    if is_address_book_app_running():
        close_app(APP_WIN_ID)


def is_address_book_app_running():
    """ Indicate if the address book app is currently running """
    return processes.is_process_running(APP)


def launch_address_book_from_launcher():
    """Drag out the launcher and tap the address book icon to start it."""
    launch_application_from_launcher(APP_WIN_ID)
    return get_address_book_app_proxy()


def get_address_book_app_proxy():
    """
    Return address book app proxy object from existing process.

    :return: Proxy object for address book application.

    """
    from ubuntu_system_tests.helpers.addressbook import _cpo  # NOQA
    proxy = autopilot.get_proxy_object_for_existing_app(APP)
    return proxy.main_window
