# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import dbus
import re


DBUS_NAME_PIM = 'com.canonical.pim'
DBUS_IFACE_ADDRESS_BOOK = 'com.canonical.pim.AddressBook'
DBUS_IFACE_ADDRESS_BOOKVIEW = 'com.canonical.pim.AddressBookView'
DBUS_OBJECT_ADDRESS_BOOK = '/com/canonical/pim/AddressBook'


class ContactsDbusService:
    def __init__(self):
        self.bus = None
        self.addr = None
        self.addr_iface = None
        self.bus = dbus.SessionBus()
        self.addr = self.bus.get_object(
            DBUS_NAME_PIM, DBUS_OBJECT_ADDRESS_BOOK)
        self.addr_iface = dbus.Interface(
            self.addr, dbus_interface=DBUS_IFACE_ADDRESS_BOOK)

    def query_contacts(self, fields='', query='', max_count=0,
                       show_invisible=False, sources=[]):
        view_path = self.addr_iface.query(
            fields, query, max_count, show_invisible, [])
        view = self.bus.get_object(
            DBUS_NAME_PIM, view_path)
        view_iface = dbus.Interface(
            view, dbus_interface=DBUS_IFACE_ADDRESS_BOOKVIEW)
        contacts = view_iface.contactsDetails([], 0, -1)
        view.close()
        return contacts

    def update_contact(self, vcard):
        return self.addr_iface.updateContacts([vcard])

    def create_contact(self, vcard):
        return self.addr_iface.createContact(vcard, "")

    def delete_contact(self, ids):
        return self.addr_iface.removeContacts(ids)

    def get_vcard_uid(self, vcard):
        """
        Return the UID of the provided vcard
        :param vcard: vcard formatted data
        :return: uid value from vcard, else None
        """
        uid_pattern = re.compile(r'^UID:(?P<uid>\S*)\r?$',
                                 re.MULTILINE | re.IGNORECASE)
        uid = None
        match = uid_pattern.search(vcard)
        if match:
            uid = match.group('uid')
        return uid

    def delete_all_contacts(self):
        """
        Delete all contacts using the dbus service
        """
        uids = []
        for contact in self.query_contacts():
            uid = self.get_vcard_uid(contact)
            if uid:
                uids.append(uid)
        self.delete_contact(uids)
