# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import subprocess


def is_bluetooth_supported():
    """Return True if Bluetooth is supported, False if it is not."""
    try:
        output = subprocess.check_output(['hcitool', 'dev'],
                                         universal_newlines=True)
    except FileNotFoundError:
        return False
    devices = output.splitlines()
    # first line always displays 'Devices:', so size needs to be > 1
    return len(devices) > 1


def enable_bluetooth():
    """Enable bluetooth through the backend."""
    subprocess.check_call(['rfkill', 'unblock', 'bluetooth'])


def disable_bluetooth():
    """Disable bluetooth through the backend."""
    subprocess.check_call(['rfkill', 'block', 'bluetooth'])


def is_bluetooth_enabled():
    """Query the backend to check if bluetooth is enabled."""
    stdout = subprocess.check_output(['rfkill', 'list', 'bluetooth'],
                                     universal_newlines=True)
    return 'Soft blocked: no' in stdout
