# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015-2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import click
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.scopes.apps import (
    launch_application_from_apps_scope
)
from ubuntu_system_tests.helpers.unity8 import (
    close_app, launch_application_from_launcher
)
from ubuntu_system_tests.helpers import wait_until

APP = 'gallery-app'
APP_NAME = 'Gallery'
APP_WIN_ID = 'com.ubuntu.gallery_gallery'
APP_CLICK = 'com.ubuntu.gallery'
APP_ICON_NAME = 'gallery-app.png'


def launch_gallery_app():
    """
    Launch the gallery app from apps scope and return proxy object.

    :return: Proxy object for gallery application.

    """
    from ubuntu_system_tests.helpers.gallery._cpo import EventsView
    launch_application_from_apps_scope(APP_NAME)
    return EventsView(get_gallery_app_proxy())


def close_gallery_app():
    """ Close the gallery app using task switcher """
    if is_gallery_app_running():
        close_app(APP_WIN_ID)


def is_gallery_app_running():
    """ Indicate if the gallery app is currently running """
    return processes.is_process_running(APP)


def get_gallery_app_proxy():
    """
    Return gallery app proxy object from existing process.

    :return: Proxy object for gallery application.

    """
    from ubuntu_system_tests.helpers.gallery._cpo import GalleryApplication
    proxy = autopilot.get_proxy_object_for_existing_app(
        APP, cleanup_process=click.get_click_app_identifier(APP_CLICK))
    return proxy.select_single(GalleryApplication)


def get_gallery_events_view():
    """Return a gallery_app EventsView custom proxy object."""
    from ubuntu_system_tests.helpers.gallery._cpo import EventsView
    return EventsView(get_gallery_app_proxy())


def get_gallery_photo_viewer():
    """Return a gallery_app PhotoViewer custom proxy object."""
    from ubuntu_system_tests.helpers.gallery._cpo import PhotoViewer
    return PhotoViewer(get_gallery_app_proxy())


def launch_gallery_app_from_launcher():
    """Drag out the launcher and tap the gallery app icon to start it."""
    launch_application_from_launcher(APP_WIN_ID)
    wait_until(is_gallery_app_running)
    return get_gallery_events_view()
