# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ubuntu_system_tests.helpers.indicators import(
    IndicatorPage,
    INDICATOR_PAGE_PATH
)
from ubuntu_system_tests.helpers.autopilot import(
    validate_dbus_object,
    click_object
)
from ubuntu_system_tests.helpers import unity8


class BluetoothIndicatorPage(IndicatorPage):
    """Autopilot helper for the bluetooth indicator page."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, unity8.UNITY8_PATH_ROOT, INDICATOR_PAGE_PATH,
            objectName='indicator-bluetooth-page')

    def _get_bluetooth_switch(self):
        """Return the bluetooth switch."""
        return self.select_single('SwitchMenu',
                                  objectName='indicator.bluetooth-enabled')

    def is_bluetooth_switch_checked(self):
        """Return true if bluetooth switch is checked, otherwise return
        false."""
        return self._get_bluetooth_switch().checked

    def enable_bluetooth(self):
        """Tap on the bluetooth checkbox to turn it on."""
        if not self.is_bluetooth_switch_checked():
            bluetooth_switch = self._get_bluetooth_switch()
            self.pointing_device.click_object(bluetooth_switch)
            bluetooth_switch.checked.wait_for(True)

    def disable_bluetooth(self):
        """Tap on the bluetooth checkbox to turn it off."""
        if self.is_bluetooth_switch_checked():
            bluetooth_switch = self._get_bluetooth_switch()
            self.pointing_device.click_object(bluetooth_switch)
            bluetooth_switch.checked.wait_for(False)

    def _get_bluetooth_settings_menu_item(self):
        """Return the bluetooth settings list item."""
        return self.select_single('StandardMenu',
                                  objectName='indicator.phone-show-settings')

    @click_object
    def open_bluetooth_settings(self):
        """Tap the bluetooth settings list item to open settings."""
        return self._get_bluetooth_settings_menu_item()
