# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import subprocess

from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.scopes.apps import (
    launch_application_from_apps_scope
)
from ubuntu_system_tests.helpers.unity8 import close_app
from ubuntu_system_tests.helpers import wait_until

APP = 'music-app'
APP_NAME = 'Music'
APP_ID = 'com.ubuntu.music'
APP_WIN_ID = 'com.ubuntu.music_music'
QML = 'music-app.qml'

CONFIG_FILE = os.path.join(fs.DIR_HOME_MUSIC_CONFIG, '{}.conf'.format(APP_ID))

FIRST_RUN_CONFIG_TEXT = 'firstRun='


def launch_music_app():
    """
    Launch the music app from apps scope and return proxy object.

    :return: Proxy object for music application.

    """
    launch_application_from_apps_scope(APP_NAME)
    wait_until(is_music_app_running, period=0.5)
    return get_music_app_proxy()


def close_music_app():
    """ Close the music app using task switcher """
    if is_music_app_running():
        close_app(APP_WIN_ID)


def is_music_app_running():
    """ Indicate if the music app is currently running """
    return processes.is_qmlscene_running_with_qmlfile(APP)


def get_music_app_proxy():
    """
    Return music app proxy object from existing process.

    :return: Proxy object for music application.

    """
    from ubuntu_system_tests.helpers.music import _cpo  # NOQA
    proxy = autopilot.get_proxy_object_for_existing_qmlscene_process(APP)
    return proxy.main_view


def stop_music_app():
    """ Stop the music app qml process """
    processes.stop_qmlscene_process(QML)


def get_current_song():
    return _get_current_url(fs.MUSIC_PREFIX)


def get_current_album():
    return _get_current_url(fs.ALBUM_PREFIX)


def _get_current_url(delimiter):
    """ Retrieve the current song based on the url parameter
    :param delimiter: The delimiter used to split the url args parameters
    """
    pid = processes.get_qmlscene_process_id(QML)
    line = processes.get_process_args(pid)
    args = line.split()
    for arg in args:
        if arg.startswith('--url='):
            return arg.split(delimiter)[1]
    return None


def set_welcome_wizard(enabled=True):
    """
    Enable/Disable first time wizard.
    :param enabled: Boolean representing if first run wizard should be enabled
    """
    replace_pattern = 's/{search}.*/{search}{value}/g'.format(
        search=FIRST_RUN_CONFIG_TEXT, value=str(enabled).lower())
    subprocess.check_call(['sed', '-i', replace_pattern, CONFIG_FILE])
