# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

import autopilot

from ubuntu_system_tests.helpers.notifications import NotificationBase
from ubuntu_system_tests.helpers.notifications.swiper import SwipeToAct
from ubuntu_system_tests.helpers.ubuntuuitoolkit import optiontoggle

logger = logging.getLogger(__name__)

BUTTONS = []


def validate(notification):
    """
    Return True if notification object is valid and looks like an incoming call
    notification.

    Note this is implemented as a static method because it is reliable
    in cases where multiple notifications are displayed and autopilot CPO
    inheritance fails.

    :param notification: The notification object to validate.

    """
    if notification and isinstance(notification, Notification):
        try:
            return (notification.secondaryIconSource ==
                    'image://theme/incoming-call')
        except autopilot.exceptions.StateNotFoundError:
            pass
    return False


class Notification(NotificationBase):

    @autopilot.logging.log_action(logger.info)
    def start_call(self):
        self._get_swiper().swipe_to_right()

    @autopilot.logging.log_action(logger.info)
    def end_call(self):
        self._get_swiper().swipe_to_left()

    def get_caller_name(self):
        return self.summary

    def get_caller_message(self):
        return self.body

    def _get_swiper(self):
        return self.select_single(SwipeToAct, visible=True)

    def dismiss(self):
        self.end_call()

    def _get_reject_option_toggle(self):
        return self.select_single(optiontoggle.OptionToggle)

    def get_reject_options(self):
        """Return a list of available reject message options."""
        return self._get_reject_option_toggle().get_options()

    def reject_call_with_message(self, message):
        """Reject the incoming call with specified message.
        :param message: The required message option text to select.
        """
        options = self._get_reject_option_toggle()
        options.select_option(message)
        self.wait_until_destroyed()
