# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import autopilot
import fixtures

from ubuntu_system_tests.helpers import ofono


def _get_keys_for_sim_pin():
    keys = ['sim_0_pin']
    if ofono.number_of_sims() == 2:
        keys.extend(['sim_1_pin'])
    return keys


class UnlockSims(fixtures.Fixture):
    """Fixture used to unlock all the SIMs"""

    def setUp(self):
        super(UnlockSims, self).setUp()
        keys = _get_keys_for_sim_pin()
        for i in range(len(keys)):
            sim_pin = autopilot.get_test_configuration()[keys[i]]
            self._unlock_sim(i, sim_pin)

    def _unlock_sim(self, index, sim_pin):
        if ofono.is_sim_inserted(index):
            if ofono.is_pin_locked(index):
                ofono.unlock_sim(index, sim_pin)
                self.addCleanup(ofono.lock_sim, index, sim_pin)


class ModemForData(fixtures.Fixture):

    def __init__(self, modem_number):
        self.modem_for_data = modem_number

    def setUp(self):
        super().setUp()
        self.previous_modem_for_data = ofono.get_modem_for_data()
        self.addCleanup(ofono.set_modem_for_data, self.previous_modem_for_data)
        ofono.set_modem_for_data(self.modem_for_data)
