# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import glob
import logging
import os
import shutil
import subprocess

from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers import timer

logger = logging.getLogger(__name__)


class DataGenerator:

    def __init__(self, src_file, dst_dir, load, update_metadata):
        self.src_file = src_file
        self.dst_dir = dst_dir
        self.load = load
        self.update_metadata = update_metadata

    def get_number_of_files(self):
        return len(glob.glob(self.dst_dir + '/*.*'))

    def _get_random_name(self):
        random_name = fs.get_random_string() + os.path.splitext(
            self.src_file)[1]
        return os.path.join(self.dst_dir, random_name)

    def replicate_files(self, number):
        for i in range(number):
            dst_file = self._get_random_name()
            if self.update_metadata:
                self._update_metadata(dst_file)
            else:
                shutil.copy(self.src_file, dst_file)

    def files_to_create(self):
        current_files = self.get_number_of_files()
        if self.load > current_files:
            return self.load - current_files
        else:
            return 0

    def create_files(self):
        num_files = self.files_to_create()
        logger.info('Creating {} files'.format(num_files))
        timer.start(timer.CUSTOM_ID)
        self.replicate_files(num_files)
        logger.info('Files created in {} seconds'.format(
            timer.stop(timer.CUSTOM_ID)))

    def _update_metadata(self, file):
        pass


class PicturesGenerator(DataGenerator):

    def __init__(self, src_file, dst_dir, load, update_metadata=False):
        super(PicturesGenerator, self).__init__(src_file, dst_dir, load,
                                                update_metadata)
        self.media_dir = fs.DIR_HOME_PICTURES
        if fs.is_media_folder_dir(fs.DIR_PICTURES):
            self.media_dir = fs.get_media_folder_dir(fs.DIR_PICTURES)

    def _update_metadata(self, file):
        name = os.path.splitext(os.path.basename(file))[0]
        cmd = 'exiftool -fast -artist={} -o {} {}'.format(name, file,
                                                          self.src_file)
        subprocess.call(cmd, stdout=open(os.devnull, 'w'),
                        stderr=subprocess.STDOUT, shell=True)
