# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot import exceptions, introspection

from ubuntu_system_tests.helpers.autopilot import (
    get_patched_registry, patched_select_single, validate_dbus_object,
    wait_select_many)
from ubuntu_system_tests.helpers.autopilot.list import order_by_y_coord
from ubuntu_system_tests.helpers.autopilot.object import get_parent
from ubuntu_system_tests.helpers.scopes.apps import _clickscope
from ubuntu_system_tests.helpers.scopes.base import GenericScopeView
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT

APP_STORE_TITLE = 'Ubuntu Store'


class GenericScopeView(_clickscope.ClickScope, GenericScopeView):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'GenericScopeView',
            objectName='clickscope')

    def go_to_store(self):
        """Over-ride base class implementation to import required CPO."""
        from ubuntu_system_tests.helpers.scopes.apps import _app_store
        registry = get_patched_registry(
            _app_store.GenericScopeView, 'GenericScopeView')
        with introspection._object_registry.patch_registry(registry):
            store = super().go_to_store()
        self.wait_for_processing_to_complete()
        return store

    def open_preview(self, category, app_name, press_duration=0.10):
        """Over-ride base class to import the required CPO.
        :parameter category: The name of the category where the application is.
        :parameter app_name: The name of the application.
        :return: The opened preview.
        """
        from ubuntu_system_tests.helpers.scopes.apps import _preview
        self.click_scope_item(category, app_name, press_duration)
        preview_list = self.wait_select_single(objectName='subPageLoader')
        preview_list.subPageShown.wait_for(True)
        preview_list.x.wait_for(0)
        self.wait_for_processing_to_complete()
        return patched_select_single(
            root=preview_list, class_object=_preview.Preview,
            class_name='Preview', objectName='preview')

    def get_app_icon(self, app_name):
        """Return icon for required app_name."""
        buttons = wait_select_many(self, type_name='UCAbstractButton',
                                   title=app_name)
        return order_by_y_coord(buttons, include_off_screen=True)[0]

    def is_app_displayed(self, app_name):
        """Return True if app with specified name is displayed."""
        try:
            self.get_app_icon(app_name)
            return True
        except exceptions.StateNotFoundError:
            return False

    def get_app_category(self, app_name):
        """Return the category name for a specified app_name."""
        app = self.get_app_icon(app_name)
        return get_parent(app, 'CardGrid').objectName
