# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot import introspection
from unity8.dash import Preview as DashPreview

from ubuntu_system_tests.helpers.autopilot import get_path_root
from ubuntu_system_tests.helpers.scopes.apps import _clickscope
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT


class Preview(DashPreview):
    """Stop the DashPreview class from being selected by Autopilot."""
    @classmethod
    def validate_dbus_object(cls, path, state):
        return False


class Preview(_clickscope.Preview, Preview):

    @classmethod
    def validate_dbus_object(cls, path, state):
        if get_path_root(path) == UNITY8_DASH_PATH_ROOT:
            name = introspection.get_classname_from_path(path)
            return (name == b'Preview' and
                    state['objectName'][1].startswith('preview'))
        return False

    def open(self):
        open_button = self._get_preview_button('open_click')
        self.pointing_device.click_object(open_button)

    def _get_preview_button(self, button, wait=False):
        object_name = 'button{}'.format(button)
        if wait:
            return self.wait_select_single(
                'PreviewActionButton', objectName=object_name)
        else:
            return self.select_single(
                'PreviewActionButton', objectName=object_name)

    def uninstall(self):
        uninstall_button = self._get_preview_button('uninstall_click')
        self.pointing_device.click_object(uninstall_button)
        self._click_confirm_uninstall_button()

    def _click_confirm_uninstall_button(self):
        confirm_button = self._get_preview_button(
            'confirm_uninstall', wait=True)
        self.pointing_device.click_object(confirm_button)

    def get_button_labels(self):
        buttons = self.select_many('PreviewActionButton')
        return [button.text for button in buttons]

    def wait_until_package_installed(self):
        self._get_preview_button('open_click', wait=True)
