# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import fixtures
import os

from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers.scopes import PHOTOS_HIDDEN, TODAY_HIDDEN


class ScopesHints(fixtures.Fixture):
    """ Fixture enable or disable the hints for today and photos scopes and
    restore their initial configuration """

    def __init__(self, hidden=True, restore=True):
        """ Create a ScopesHints Fixture class
        :param hidden: if True, then the 'Skip' button won't be displayed in
        the scopes, otherwise the buttons will be displayed.
        :param restore: If True, then restore the scope to its previous state
                        on cleanup, otherwise leave in current state.

        """
        self.hidden = hidden
        self.restore = restore
        self.all_hints = self._get_all_hints()

    def setUp(self):
        super().setUp()

        if self.hidden:
            self._create_hint_files()
        else:
            self._delete_hint_files()

    def _get_all_hints(self):
        return [PHOTOS_HIDDEN, TODAY_HIDDEN]

    def _ensure_hint_restored(self, file):
        if self.restore:
            if os.path.exists(file):
                self.addCleanup(fs.create_empty_file, file)
            else:
                self.addCleanup(fs.delete_file, file)

    def _create_hint_files(self):
        for file in self.all_hints:
            self._ensure_hint_restored(file)
            fs.create_empty_file(file)

    def _delete_hint_files(self):
        for file in self.all_hints:
            self._ensure_hint_restored(file)
            fs.delete_file(file)
