# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers.autopilot import (
    patched_wait_select_single, validate_dbus_object)
from ubuntu_system_tests.helpers.scopes.base import GenericScopeView
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT


class GenericScopeView(GenericScopeView):
    """
    This class represents the preview screen that is part of the
    GenericScopeView and implement the methods specific to the Artist Preview.
    """

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'GenericScopeView',
            objectName='musicaggregator')

    def _get_button_by_title(self, title):
        """Return track button of specified title."""
        tracks = self.select_single(objectName='tracks')
        return tracks.select_single(
            objectName='trackTitleLabel', text=title)

    def _get_track_list_view(self):
        """Return the track list view that can be swiped up and down."""
        return self.select_single(
            'QQuickListView', objectName='previewListRow0')

    def _click_button_by_title(self, title):
        """ Click in the button with the desired title """
        button = self._get_button_by_title(title)
        self._get_track_list_view().swipe_child_into_view(button)
        self.pointing_device.click_object(button)

    def select_track(self, track):
        """Click on the track with the desired name and return Preview."""
        from ubuntu_system_tests.helpers.scopes.music import _track
        self._click_button_by_title(track)
        return patched_wait_select_single(
            root=self, class_object=_track.Preview, class_name='Preview',
            objectName='preview', visible=True)

    def select_album(self, album):
        """Click on the track with the desired name and return Preview."""
        from ubuntu_system_tests.helpers.scopes.music import _album
        self._click_button_by_title(album)
        return patched_wait_select_single(
            root=self, class_object=_album.Preview, class_name='Preview',
            objectName='preview0', visible=True)
