# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from datetime import datetime

from ubuntuuitoolkit import UbuntuUIToolkitCustomProxyObjectBase

from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers.autopilot.object import (
    wait_until_is_not_moving)
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT


class Preview(UbuntuUIToolkitCustomProxyObjectBase):
    """
    This class represents the preview screen that is part of the
    GenericScopeView and implement the methods specific to the Photos
    Preview.
    """

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'Preview')

    def get_open_button(self):
        return self.select_single('PreviewActionButton',
                                  objectName='buttonopen',
                                  visible=True)

    def _get_labels_with_text(self, text):
        labels = self.select_many('UCLabel', objectName='textLabel')
        for label in labels:
            if text in label.text:
                return label
        return None

    def get_date(self):
        """ Retrieve a date following the format used in the preview """
        text = self._get_labels_with_text('Date').text.split(':')[1].strip()
        return datetime.strptime(text, '%A, %B %d, %Y').date()

    def get_time(self):
        """ Retrieve a time following the format used in the preview """
        text = ' '.join(self._get_labels_with_text('Time').text.split(' ')[1:])
        return datetime.strptime(text, '%I:%M:%S %p %Z').time()

    def get_thumbnail(self):
        return self.select_single('LazyImage', objectName='lazyImage')

    def is_open_button_pressed(self):
        return self.get_open_button().pressed

    def click_open_button(self):
        button = self.get_open_button()
        wait_until_is_not_moving(button)
        self.pointing_device.click_object(button)
