# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot import exceptions

from ubuntu_system_tests.helpers.autopilot import (
    patched_wait_select_single,
    is_element,
    validate_dbus_object,
    wait_select_many
)
from ubuntu_system_tests.helpers.scopes.base import GenericScopeView
from ubuntu_system_tests.helpers.unity8 import UNITY8_DASH_PATH_ROOT


class GenericScopeView(GenericScopeView):
    """
    This class represents the preview screen that is part of the
    GenericScopeView and implement the methods specific to the Video Scope.
    """

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'GenericScopeView',
            objectName='videoaggregator')

    def is_in_search_result(self, text):
        """ Indicate if a text is part of the search result as video label """
        try:
            self.wait_select_single(
                'UCLabel', objectName='titleLabel', text=text, visible=True)
            return True
        except exceptions.StateNotFoundError:
            return False

    def _get_my_videos_section(self):
        wait_select_many(self, timeout=30, objectName='dashCategorylocal')
        return self.select_single(
            objectName='dashCategorylocal').select_single('QQuickGridView')

    def get_my_videos_thumbnails(self):
        """
        Retrieve all the titles and thumbnails displayed for all the songs in
        my music section
        """
        labels = []
        sources = []

        videos = self.get_my_videos()
        for video in videos:
            labels.append(video.select_single(objectName='titleLabel').text)
            sources.append(video.select_single(objectName='artImage').source)
        return labels, sources

    def get_my_videos(self):
        """ Retrieve all the youtube videos """
        self.wait_for_processing_to_complete()
        buttons = self._get_videos(self._get_my_videos_section())
        return buttons

    def is_my_videos_displayed(self):
        """ Indicate if the my videos section is being displayed """
        is_element(self._get_my_videos_section)

    def _get_youtube_category(self):
        return self.select_single(
            'DashCategoryBase', category='com.ubuntu.scopes.youtube_youtube')

    def _get_videos(self, category):
        buttons = category.select_many('UCAbstractButton')
        return [button for button in buttons if
                'delegate' in button.objectName and button.title]

    def get_youtube_videos(self):
        """ Retrieve all the youtube videos """
        self.wait_for_processing_to_complete()
        return self._get_videos(self._get_youtube_category())

    def select_video(self, video):
        """ Select a video in the youtube section """
        self.pointing_device.click_object(video)
        self.wait_for_processing_to_complete()
        from ubuntu_system_tests.helpers.scopes.video import _preview
        return patched_wait_select_single(
            root=self, class_object=_preview.Preview, class_name='Preview',
            objectName='preview')
