# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os
import subprocess

from ubuntu_system_tests.helpers.power import (
    write_to_powerd_fifo, LIGHT_SENSOR_MAX, LIGHT_SENSOR_MID, LIGHT_SENSOR_MIN)
from ubuntu_system_tests.helpers.testbed import run_command_with_sudo as sudo

SENSOR_OVERRIDE = 'UBUNTU_PLATFORM_API_TEST_OVERRIDE=sensors'


def are_fake_sensors_enabled_for_process(pid):
    """Return True if fake sensors enabled for specified process."""
    if not os.path.exists('/tmp/sensor-fifo-{}'.format(pid)):
        return False

    try:
        output = sudo('cat /proc/{pid}/environ'.format(pid=pid)).decode()
    except subprocess.CalledProcessError:
        return False
    return output.find(SENSOR_OVERRIDE) >= 0


def _set_light_level(level, wait=1):
    """Set light sensor to specified value.
    :param value: Light level value.
    :param wait: How long to wait in ms before applying value.
    """
    cmd = '{} light {}'.format(wait, level)
    write_to_powerd_fifo([cmd])


def _set_proximity(value, wait=1):
    """Set proximity sensor to specified value.
    :param value: Either 'near' or 'far'.
    :param wait: How long to wait in ms before applying value.
    """
    cmd = '{} proximity {}'.format(wait, value)
    write_to_powerd_fifo([cmd])


def set_proximity_near(wait=1):
    """Set proximity sensor to near.
    :param wait: How long to wait in ms before applying value.
    """
    _set_proximity('near', wait)


def set_proximity_far(wait=1):
    """Set proximity sensor to far.
    :param wait: How long to wait in ms before applying value.
    """
    _set_proximity('far', wait)


def set_light_level_bright(wait=1):
    """Set light sensor to bright.
    :param wait: How long to wait in ms before applying value.
    """
    _set_light_level(LIGHT_SENSOR_MAX, wait)


def set_light_level_dark(wait=1):
    """Set light sensor to dark.
    :param wait: How long to wait in ms before applying value.
    """
    _set_light_level(LIGHT_SENSOR_MIN, wait)


def set_light_level_mid(wait=1):
    """Set light sensor to mid-range value.
    :param wait: How long to wait in ms before applying value.
    """
    _set_light_level(LIGHT_SENSOR_MID, wait)
