
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ubuntuuitoolkit import UbuntuUIToolkitCustomProxyObjectBase
from ubuntu_system_tests.helpers.autopilot.list import order_by_y_coord


class OptionToggle(UbuntuUIToolkitCustomProxyObjectBase):
    """CPO to represent a drop-down list of options."""

    def expand(self):
        """Expand option list so all options are displayed."""
        if not self.expanded:
            self.pointing_device.click_object(self)
            self.expanded.wait_for(True)

    def contract(self):
        """Contract option list so options are hidden."""
        if self.expanded:
            self.pointing_device.click_object(self)
            self.expanded.wait_for(False)

    def get_options(self):
        """Return ordered list of availble options."""
        options = order_by_y_coord(self.select_many('UCLabel'))
        return [option.text for option in options]

    def select_option(self, option):
        """Select an option by option text value.
        :param option: Text value of required option.
        """
        self.expand()
        self.pointing_device.click_object(self.select_single(text=option))
