# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2014, 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntuuitoolkit import UbuntuUIToolkitCustomProxyObjectBase
from unity8 import process_helpers

from autopilot import introspection
from autopilot.matchers import Eventually
from testtools.matchers import Equals

from ubuntu_system_tests.helpers import context
from ubuntu_system_tests.helpers import timer
from ubuntu_system_tests.helpers.unity8 import greeter

UNITY8_PATH_ROOT = b'unity8'
UNITY8_DASH_PATH_ROOT = b'unity8-dash'

APP_ID_DASH = 'unity8-dash'


def ensure_unity_stopped():
    if _is_unity8_running():
        process_helpers.stop_job('unity8')
    Eventually(Equals(False), timeout=300).match(_is_unity8_running)


def ensure_unity_running_and_greeter_hidden():
    if not _is_unity8_running():
        process_helpers.start_job('unity8')
        greeter.wait_for_greeter()

    greeter.hide_greeter_with_dbus()


def _is_unity8_running():
    return process_helpers.is_job_running('unity8')


def get_dash():
    """Return the Unity8 Dash autopilot custom proxy object."""
    from ubuntu_system_tests.helpers.unity8.dash import Dash
    pid = process_helpers.get_job_pid('unity8-dash')
    dash_proxy = introspection.get_proxy_object_for_existing_process(
        pid=pid,
        emulator_base=UbuntuUIToolkitCustomProxyObjectBase,
    )
    return dash_proxy.select_single(Dash)


def launch_application_from_launcher(app_name):
    """
    Launch an app from the launcher.

    :param app_name: Name of the displayed application.

    """
    unity = context.shared.unity
    timer.start(timer.LAUNCH_ID)
    unity.main_window.launch_application(app_name)


def close_app(app_name):
    """Close an app using task switcher and check process is stopped."""
    unity = context.shared.unity

    # Get the windows name
    stage = unity.main_window.swipe_to_show_app_switcher()
    app_window_name = 'appWindow_' + app_name
    app_windows = stage.get_app_window_names()
    if app_window_name not in app_windows:
        raise RuntimeError(
            'Window {} no included in windows list {}'.format(
                app_window_name, app_windows
            ))

    # Close the windows and assert that it is closed
    stage.close_app(app_name)
    app_windows = stage.get_app_window_names()
    if app_window_name in app_windows:
        raise RuntimeError(
            'Window {} not closed correctly'.format(app_window_name))
