# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import autopilot
import logging

import ubuntuuitoolkit as uitk

from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers.ubuntuuitoolkit import _qquicktextinput
from ubuntu_system_tests.helpers.unity8 import UNITY8_PATH_ROOT

logger = logging.getLogger(__name__)


class PassphraseLockscreen(uitk.UbuntuUIToolkitCustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_PATH_ROOT, b'PassphraseLockscreen')

    def get_text_input(self):
        """Return textfield for entering passphrase."""
        return self.select_single(
            _qquicktextinput.QQuickTextInput, objectName='pinentryField',
            visible=True)

    @autopilot.logging.log_action(logger.info)
    def unlock(self, passphrase):
        """Enter passphrase to unlock screen."""
        if not passphrase.endswith('\n'):
            passphrase += '\n'
        self.get_text_input().write(passphrase, clear=False)
