# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import requests
import subprocess
import tempfile

from ubuntu_system_tests.helpers import context
from ubuntu_system_tests.helpers.file_system import delete_file


def download_file(url, save_location=None):
    """
    Download a file from specified url and return the path of the saved file.

    If save_location is None then a temporary file path will be assigned,
    otherwise the specified location will be used.

    The downloaded file will automatically be added to test cleanup actions.

    :param url: Url of the file to download.
    :param save_location: Location to save file to.
    :return: Path of saved file on local file system.

    """
    if not save_location:
        save_location = tempfile.NamedTemporaryFile(delete=False).name
    subprocess.check_call(['wget', url, '-O', save_location],
                          stdout=subprocess.DEVNULL,
                          stderr=subprocess.DEVNULL)
    context.shared.add_cleanup(delete_file, save_location)
    return save_location


def exists(url):
    """ Indicate if the url exists """
    response = requests.head(url)
    return response.status_code == requests.codes.ok
