# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging


from ubuntu_system_tests import config
from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers.platform import (
    get_channel_name, get_device_name, get_build_number)

from ubuntu_system_tests.tests.base import BaseUbuntuSystemTestCase

logger = logging.getLogger(__name__)

RUN_ID = fs.get_random_string()


def load_config_values(key, default=None):
    config_stack = config.get_device_config_stack()
    try:
        return config_stack.get(key)
    except KeyError:
        return default


def log_time(data):
    logger.info('Time => {}'.format(data))


def log_global_info():
    global_info = {'run_id': RUN_ID,
                   'device': get_device_name(),
                   'channel': get_channel_name(),
                   'build_number': get_build_number()}

    logger.info('Global Info <= {}'.format(global_info))


class PerfTestCase(BaseUbuntuSystemTestCase):

    def setUp(self):
        super().setUp()
        log_global_info()
