# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging
import testscenarios

from threading import Event

from ubuntu_system_tests.helpers import context
from ubuntu_system_tests.helpers import mediascanner
from ubuntu_system_tests.helpers import timer

from ubuntu_system_tests.tests.perf import (
    PerfTestCase, log_time, load_config_values)

logger = logging.getLogger(__name__)

TYPE_HOME = 'home'
TYPE_SDCARD = 'sdcard'
CLASS = 'scalability'
PERF_ID = 'perf'


def get_scenarios(key):
    """ Retrieve the scenarios dict based on the loads in the config """
    loads = load_config_values(key)
    scenarios = []
    count = 0
    if loads:
        for load in loads.split(','):
            scenarios.append(('iter_{}'.format(count), {'load': int(load)}))
            count += 1
    return scenarios


class BaseScalabilityTestCase(PerfTestCase, testscenarios.TestWithScenarios):

    def setUp(self):
        super().setUp()
        self.data_gen = None
        self.type = None
        context.shared.retry_time = 180000

    def _log_completed(self, name, timer_id):
        data = {'name': name, 'time': timer.stop(timer_id), 'type': self.type,
                'class': CLASS, 'load': self.data_gen.load}
        log_time(data)

    def _run(self, test_method, data_processed):
        self.shell = self.restart_unity()
        mediascanner.stop_media_scanner()

        scan_completed = Event()
        observer = mediascanner.start_mediascanner_observer(
            scan_completed, self.data_gen.files_to_create())
        self.addCleanup(observer.stop)
        self.data_gen.create_files()

        timer.start(PERF_ID)
        mediascanner.start_media_scanner()
        scan_completed.wait()
        self._log_completed(data_processed, PERF_ID)

        test_method()
