# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers import context
from ubuntu_system_tests.helpers.data import load_test_metadata
from ubuntu_system_tests.helpers import media
from ubuntu_system_tests.helpers.url_dispatcher import go_to_url
from ubuntu_system_tests.tests import base

SKIP_REASON = 'Scope not required for the current device and channel'


class BaseScopeTestCase(base.BaseUbuntuSystemTestCase):
    """This Class tests the scopes"""

    def setUp(self):
        super().setUp()
        self.unity_proxy = self.restart_unity()
        self.dash = context.shared.dash
        self.useFixture(media.BackupRestoreLocalMediaFixture())
        self.test_metadata = load_test_metadata()
        current_scope_url = self.dash.get_current_scope().get_url()
        self.addCleanup(go_to_url, current_scope_url)

    def _validate_header_title(self, expected_title):
        header = self.dash.get_current_page_header()
        self.assertEqual(header.title, expected_title)

    def _clear_search_and_validate_header_title(self, expected_title):
        """
        Clear search on current header and validate that the header page has
        the expected title.
        :param expected_title: Expected title of new header.

        """
        self.dash.get_current_page_header().clear_search()
        self._validate_header_title(expected_title)

    def _go_back_and_validate_header_title(self, expected_title):
        """
        Press back button on current header and validate that the next
        header page has the expected title.
        :param expected_title: Expected title of new header.

        """
        self.dash.get_current_page_header().go_back()
        self._validate_header_title(expected_title)
