# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot.matchers import Eventually
from testtools.matchers import Equals

from ubuntu_system_tests.helpers.indicators import(
    network as network_indicator_helpers
)
from ubuntu_system_tests.helpers import network
from ubuntu_system_tests.helpers import system_settings
from ubuntu_system_tests.tests import base


class BatterySettingsTestCase(base.BaseUbuntuSystemTestCase):

    def setUp(self):
        super().setUp()
        self.shell = self.restart_unity().main_window
        self.system_settings = system_settings.launch_system_settings()
        self.assertTrue(network.is_wifi_connected())

    def _disable_mobile_data_if_enabled(self):
        """Disable mobile data if its already enabled"""
        if network.is_mobile_data_enabled():
            network.turn_off_data_connection()
            self.addCleanup(network.turn_on_data_connection)

    def test_disable_wifi_from_battery_settings(self):
        """
        1. Open system settings and go to battery panel
        2. Scroll to the bottom and turn off wifi switch
        3. Ensure wifi gets turned off
        """
        self._disable_mobile_data_if_enabled()

        battery_page = self.system_settings.go_to_battery_page()
        self.assertTrue(battery_page.is_wifi_switch_checked())
        battery_page.turn_off_wifi()
        self.addCleanup(network.turn_on_wifi_ensure_connectivity,
                        test_case=self, timeout=30)

        self.assertThat(lambda: network.check_connection(),
                        Eventually(Equals(False)))

        network_indicator = network_indicator_helpers.open_network_indicator()
        self.assertFalse(network_indicator.is_wifi_enabled())
        self.assertTrue(
            network_indicator.get_number_of_wifi_access_points() == 0)
