# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

from ubuntu_system_tests.helpers import wait_until
from ubuntu_system_tests.helpers.location.fixture_setup import (
    DummyLocation, SetLocationAccessRequests
)
from ubuntu_system_tests.helpers import webapp
from ubuntu_system_tests.helpers.location.coordinates import EIFFEL_TOWER
from ubuntu_system_tests.helpers.webapp import here
from ubuntu_system_tests.tests.webapps import BaseWebAppTestCase

logger = logging.getLogger(__name__)


class HereTestCase(BaseWebAppTestCase):

    PARIS = 'Paris'
    LOCATION_APP = 'com.nokia.heremaps_here'

    def setUp(self):
        self.useFixture(DummyLocation(*EIFFEL_TOWER))
        super().setUp()
        self.useFixture(SetLocationAccessRequests(self.LOCATION_APP))
        self.webapp = here.launch_here_webapp()
        self.driver = webapp.get_webdriver(self.addCleanup)

    def test_retrieve_location(self):
        """ Open the HERE maps app and validate that the current location is
        the same than the one that was set in the DummyLocation Fixture
        """
        homepage = here.Homepage(self.driver)
        homepage.go_to_my_location()

        # Tap on the center of the map to display the place located there
        x, y = self.webapp.get_webapp_view().get_coords()[:2]
        width, height = homepage.get_map_size()
        homepage.tap_at(x + int(width * 0.5), y + int(height * 0.5))

        # Validate the place displayed in the map is correct
        self.assertTrue(
            wait_until(lambda: self.PARIS in self.driver.page_source))
